summaryrefslogtreecommitdiff
path: root/Source/Core/VideoCommon/Src/OpcodeDecoding.cpp
diff options
context:
space:
mode:
authorJordan Woyak <jordan.woyak@gmail.com>2011-01-31 01:28:32 +0000
committerJordan Woyak <jordan.woyak@gmail.com>2011-01-31 01:28:32 +0000
commitfbaf9659958cd6d8c0df6b0c217f6e60f57f9d77 (patch)
tree3ddd90222b5d7afd0c98b936ab4c9e37375ec919 /Source/Core/VideoCommon/Src/OpcodeDecoding.cpp
parentae7c64ec134799183487adb5104c6908cf282240 (diff)
Eliminated the plugin interface. Merged DX9/DX11/OGL video plugins into Dolphin. It could still use a lot of cleanup. Lots of things are still named "plugin". Software renderer is temporarily disabled until it gets some namespaces. I only updated vs08/10, Linux/OSX builds are broken.
git-svn-id: https://dolphin-emu.googlecode.com/svn/trunk@6996 8ced0084-cf51-0410-be5f-012b33b47a6e
Diffstat (limited to 'Source/Core/VideoCommon/Src/OpcodeDecoding.cpp')
-rw-r--r--Source/Core/VideoCommon/Src/OpcodeDecoding.cpp19
1 files changed, 11 insertions, 8 deletions
diff --git a/Source/Core/VideoCommon/Src/OpcodeDecoding.cpp b/Source/Core/VideoCommon/Src/OpcodeDecoding.cpp
index 8641e0db73..14c8e94173 100644
--- a/Source/Core/VideoCommon/Src/OpcodeDecoding.cpp
+++ b/Source/Core/VideoCommon/Src/OpcodeDecoding.cpp
@@ -30,6 +30,9 @@
#include "OpcodeDecoding.h"
#include "CommandProcessor.h"
#include "CPUDetect.h"
+#include "Core.h"
+#include "Host.h"
+#include "HW/Memmap.h"
#include "VertexLoaderManager.h"
@@ -95,9 +98,9 @@ static void Decode();
void InterpretDisplayList(u32 address, u32 size)
{
u8* old_pVideoData = g_pVideoData;
- u8* startAddress = Memory_GetPtr(address);
+ u8* startAddress = Memory::GetPointer(address);
- // Avoid the crash if Memory_GetPtr failed ..
+ // Avoid the crash if Memory::GetPointer failed ..
if (startAddress != 0)
{
g_pVideoData = startAddress;
@@ -201,16 +204,16 @@ bool FifoCommandRunnable()
else
{
// TODO(Omega): Maybe dump FIFO to file on this error
- char szTemp[1024];
- sprintf(szTemp, "GFX FIFO: Unknown Opcode (0x%x).\n"
+ char szTemp[1024];
+ sprintf(szTemp, "GFX FIFO: Unknown Opcode (0x%x).\n"
"This means one of the following:\n"
"* The emulated GPU got desynced, disabling dual core can help\n"
"* Command stream corrupted by some spurious memory bug\n"
"* This really is an unknown opcode (unlikely)\n"
"* Some other sort of bug\n\n"
"Dolphin will now likely crash or hang. Enjoy." , cmd_byte);
- g_VideoInitialize.pSysMessage(szTemp);
- g_VideoInitialize.pLog(szTemp, TRUE);
+ Host_SysMessage(szTemp);
+ Core::Callback_VideoLog(szTemp, TRUE);
{
SCPFifoStruct &fifo = CommandProcessor::fifo;
@@ -234,8 +237,8 @@ bool FifoCommandRunnable()
,fifo.bFF_BPEnable ? "true" : "false" ,fifo.bFF_BPInt ? "true" : "false"
,fifo.bFF_Breakpoint ? "true" : "false");
- g_VideoInitialize.pSysMessage(szTmp);
- g_VideoInitialize.pLog(szTmp, TRUE);
+ Host_SysMessage(szTmp);
+ Core::Callback_VideoLog(szTmp, TRUE);
}
}
break;